---
title: Services
visible: true
---

List of public services provided by the burble.dn42 network.

===

#Services

## Public Website

[burble.dn42](http://burble.dn42/) (dn42 link)  
[dn42.burble.com](https://dn42.burble.com/) (public internet link)

This website is built using [GRAV](https://getgrav.org/) and currently
hosted on dn42-fr-sbg1.  The public internet version is protected by
[CloudFlare](https://www.cloudflare.com).  
Longer term, regional replicas of the DN42 site may be provided however
this is not currently configured.

## Looking Glass

[lg.burble.com](https://lg.burble.com) (public internet link)  
[lg.burble.dn42](https://lg.burble.dn42) (dn42 link)

The burble.dn42 looking glass is based on [bird-lg](https://github.com/sileht/bird-lg) with patches by
[Zhaofeng](https://github.com/zhaofengli/bird-lg), [tds](https://github.com/TimStallard/bird-lg) and
[myself](https://github.com/sesa-me/bird-lg) to fix formating, bird2 compatibility and other tweaks.

A fork of sileht/bird-lg that includes all of our fixes is available on [GitHub](https://github.com/sesa-me/bird-lg).

DN42 registry data in the BGP Map part of the looking glass uses [lgregmapper](https://git.dn42.us/burble/lgregmapper)
to interface with [dn42regsrv](https://git.dn42.us/burble/dn42regsrv). 

The looking glass is hosted on fr-sbg1 behind [CloudFlare](https://www.cloudflare.com).  

## DNS

|Authoritative Service||
|:--|:--|
| ns1.burble.dn42<br/>b.delegation-servers.dn42| 172.20.129.1<br/>fd42:4242:2601:ac53::1 |

|Recursive Service||
|:--|:--|
| dns.burble.dn42<br/>b.recursive-servers.dn42| 172.20.129.2<br/>fd42:4242:2601:ac53::53 |
<br/>
**DNS over HTTPs (DoH)**

* https://dns.burble.dn42/dns-query
* https://[fd42:4242:2601:ac53::53]/dns-query
* https://172.20.129.2/dns-query

burble.dn42 provides a local, anycast, authoritative and recursive DNS service.  
The [DNS Service](/home/dns) has it's own page.

## DN42 Wiki Mirror

|Mirror URLs||
|:--|:--|
| [wiki.dn42](https://wiki.dn42/)&nbsp;| (editable via DN42)|
| [wiki.burble.dn42](https://wiki.burble.dn42/)&nbsp;| (editable via DN42)|
| [dn42.dev](http://dn42.dev/)&nbsp;| (read-only via public internet)|
| [wiki.burble.com](http://wiki.burble.com/)&nbsp;| (read-only via public internet)|
<br/>
burble.dn42 maintains a globally distributed mirror of the DN42 Wiki, and is part of
the wiki.dn42 anycast group. 
The DN42 services ([wiki.dn42](https://wiki.dn42/) and
[wiki.burble.dn42](https://wiki.burble.dn42/)) are editable, whilst the public internet
views ([dn42.dev](https://dn42.dev/) and [wiki.burble.com](https://wiki.burble.com/) are
read-only.

Please note that updates to the wiki may take several hours to sync with other mirrors.

The service is provided by regional mirrors fronted by an nginx proxy that is itself
anycasted across burble.dn42. The service is fully meshed and will continue to
operate as long as at least one proxy and mirror is available. The maximum latency
across the network is &lt;80ms.  
Mirrors are located in the following locations:

* dn42-fr-sbg1
* dn42-ca-bhs2
* dn42-us-dal1
* dn42-sg-sin1

## Pingable IP address

* pingable.burble.dn42
* 172.20.129.5
* fd42:4242:2601:ac05::1

pingable.burble.dn42 is a single IP address that will respond to ping and
traceroute requests across the entire network.

This address may be used for automated reachability or latency tests, however
please be considerate and configure a reasonable test frequency. In all cases,
do not set the ping frequency to be higher than once a second. 

## Registry API Service and Explorer

[dn42regsrv](https://git.dn42.us/burble/dn42regsrv) is a REST API for the DN42 registry
that provides a bridge between interactive applications and the registry.

As well as the main REST API to the DN42 registry, the server can also generate ROA tables
and provides a small web application for exploring registry data.

A public instance of the API and associated explorer web app is available at the
following URLs:

* [https://explorer.burble.com/](https://explorer.burble.com/) (public internet link)
* [http://explorer.collector.dn42/](http://explorer.collector.dn42/) (DN42 link)

## Global Route Collector

* [https://grc.burble.com/](https://grc.burble.com/) (public internet link)
* [https://lg-grc.burble.com/](https://lg-grc.burble.com/) (public internet link)
* [http://collector.dn42/](http://collector.dn42/) (DN42 link)
* [http://lg.collector.dn42/](http://lg.collector.dn42/) (DN42 link)
* ssh shell@collector.dn42

The [global route collector](https://git.dn42.us/burble/grc) provides a central
bird instance that collects routes from peers across the DN42 network.  
All users are invited to join the collector and help provide stats for the network.

The route collector can currently be queried by using ssh to connect a bird shell
or via a looking glass.  
Additional services and stats are expected to be developed in the future. 

## ROA Data

Route Origin Authorisation (ROA) tables are generated using
[dn42regsrv](https://git.dn42.us/burble/dn42regsrv) and published to the
[dn42.burble.com](https://dn42.burble.com/) website for general use.

The JSON output file can be used with [gortr](https://github.com/cloudflare/gortr)
to implement ROA checks via RPKI.  
The Bird files can be used directly with Bird to implement ROA checks as detailed
in the DN42 Wiki ([Bird1](https://dn42.net/howto/Bird) / [Bird2](https://dn42.net/howto/Bird2)).

|URL|&nbsp;IPv4/IPv6&nbsp;|Description|
|---|---|---|
|[https://dn42.burble.com/roa/dn42_roa_46.json](https://dn42.burble.com/roa/dn42_roa_46.json) &nbsp; | &nbsp;Both&nbsp; | &nbsp; DN42 ROA data in JSON format |
|[https://dn42.burble.com/roa/dn42_roa_bird1_46.conf](https://dn42.burble.com/roa/dn42_roa_bird1_46.conf) &nbsp; | &nbsp;Both&nbsp; | &nbsp; DN42 ROA data for use with Bird1 |
|[https://dn42.burble.com/roa/dn42_roa_bird1_4.conf](https://dn42.burble.com/roa/dn42_roa_bird1_4.conf) &nbsp; | &nbsp;IPv4 Only&nbsp; | &nbsp; DN42 ROA data for use with Bird1 |
|[https://dn42.burble.com/roa/dn42_roa_bird1_6.conf](https://dn42.burble.com/roa/dn42_roa_bird1_6.conf) &nbsp; | &nbsp;IPv6 Only&nbsp; | &nbsp; DN42 ROA data for use with Bird1 |
|[https://dn42.burble.com/roa/dn42_roa_bird2_46.conf](https://dn42.burble.com/roa/dn42_roa_bird2_46.conf) &nbsp; | &nbsp;Both&nbsp; | &nbsp; DN42 ROA data for use with Bird2 |
|[https://dn42.burble.com/roa/dn42_roa_bird2_4.conf](https://dn42.burble.com/roa/dn42_roa_bird2_4.conf) &nbsp; | &nbsp;IPv4 Only&nbsp; | &nbsp; DN42 ROA data  for use with Bird2 |
|[https://dn42.burble.com/roa/dn42_roa_bird2_6.conf](https://dn42.burble.com/roa/dn42_roa_bird2_6.conf) &nbsp; | &nbsp;IPv6 Only&nbsp; | &nbsp; DN42 ROA data  for use with Bird2 |

## NTP Service

All servers in burble.dn42 are part of the [NTP Pool Project](https://www.ntppool.org/) and provide a stable, high
stratum NTP service using [chrony](https://chrony.tuxfamily.org). You can see my pool status in my
[NTP Pool Profile Page](https://www.ntppool.org/user/buovss4oiceotdj2o3mb).

The NTP service is exposed over DN42, and users are welcome to use any server in the burble.dn42 network as an
NTP time server on either the public or DN42 networks.

## Lounge IRC Gateway

[lounge.burble.dn42](http://lounge.burble.dn42/) (dn42 link)  
[lounge.burble.com](https://lounge.burble.com/) (public internet link)

The burble.dn42 IRC web gateway is based on [thelounge](https://thelounge.chat/)
and is provided for DN42 users to access and lurk on the
[#dn42](https://wiki.dn42.us/services/IRC) IRC channel hosted at
[hackint](https://www.hackint.org/).

Please mail [dn42@burble.com](mailto:dn42@burble.com) for an account.  
Note that the service is strictly limited to hackint channels.

## Public Git Repository

[git.burble.dn42](http://git.burble.dn42/) (dn42 link)  
[git.burble.com](https://git.burble.com/) (public internet link)

burble.dn42 related code and configuration is mastered on a local git
repository before being pushed to other public repositories.

Whilst primarily a restricted service, with the intent of making burble.dn42
configuration and code publically available, user accounts can be created on request.
Please mail [dn42@burble.com](mailto:dn42@burble.com) for further details.

## DN42 Hosting Service

Contact dn42@burble.com if you have a DN42 service that you would like
to host on burble.dn42


## Network Status and Reporting

### Hosted Grafana Service

[http://grafana.burble.dn42](http://grafana.burble.dn42) dn42 link  
[https://grafana.burble.com](https://grafana.burble.com) public internet link

The hosted grafana service has it's own page [here](/home/grafana-service).

### DN42 Infrastructure Monitoring

burble.dn42 hosts monitoring and alerting of key DN42 services, see the
[hosted grafana service](/home/grafana-service) for more details.

### burble.dn42 status

[dn42.status.burble.com](https://dn42.status.burble.com/)

Each node in the network is monitored by [UptimeRobot](https://uptimerobot.com/) with alerts
if a node becomes unavailable. 

Internally, nodes are measured by [netdata](https://github.com/netdata/netdata) which provides
a real time view of each node. [prometheus](https://prometheus.io/) is then used to collect and
store that data for historical reporting. [grafana](https://grafana.com/) is used for
visualisation. Some public graphs are available on the [hosted grafana service](/home/grafana-service).

Syslogs are exported in real time to a central logging node on the internal network.